/*
	Copyright (C) 2025  snoutie
	Authors: snoutie (copyright@achtarmig.org)
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU Affero General Public License as published
	by the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU Affero General Public License for more details.

	You should have received a copy of the GNU Affero General Public License
	along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

package table

import (
	_ "embed"
	"sap-cds-search/cmd/database"
)

type CDSView struct {
	TechnicalName string `json:"Name"`
	DisplayName   string `json:"DisplayName"`
	Description   string `json:"Description"`
	Version       string `json:"Version"`
	State         string `json:"State"`
	CreatedAt     int    `json:"CreatedAt"`
	ModifiedAt    int    `json:"ModifiedAt"`
}

//go:embed sql/query_cds_view.sql
var query_cds_view string

func GetCDSView(TechnicalName string) (*CDSView, error) {
	row := database.DB.QueryRow(query_cds_view, TechnicalName)

	var CDSView CDSView
	err := row.Scan(&CDSView.TechnicalName, &CDSView.DisplayName, &CDSView.Description, &CDSView.Version, &CDSView.State, &CDSView.CreatedAt, &CDSView.ModifiedAt)
	if err != nil {
		return nil, err
	}

	return &CDSView, nil
}

//go:embed sql/query_all_cds_view_technical_names.sql
var query_all_cds_view_technical_names string

func QueryAllCDSViewTechnicalNames() (*[]string, error) {
	rows, err := database.DB.Query(query_all_cds_view_technical_names)
	if err != nil {
		return nil, err
	}

	var technicalNames []string
	for rows.Next() {
		var technicalName string
		err := rows.Scan(&technicalName)
		if err != nil {
			return nil, err
		}
		technicalNames = append(technicalNames, technicalName)
	}

	return &technicalNames, nil
}
